@@ -1,5 +1,6 @@
 import tempfile
 import typing as t
+from contextlib import suppress
 from pathlib import Path
 
 import jinja2
@@ -191,7 +192,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "stages": ["pre-push", "manual"],
             "args": ["-c", "pyproject.toml", "-r", "-ll"],
             "files": "^crackerjack/.*\\.py$",
-            "exclude": None,
+            "exclude": r"^tests/",
             "additional_dependencies": None,
             "types_or": None,
             "language": None,
@@ -283,9 +284,9 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "tier": 3,
             "time_estimate": 0.1,
             "stages": ["pre-push", "manual"],
-            "args": ["crackerjack"],
+            "args": ["crackerjack", "--exclude", "tests"],
             "files": None,
-            "exclude": None,
+            "exclude": r"^tests/",
             "additional_dependencies": None,
             "types_or": None,
             "language": "system",
@@ -337,9 +338,9 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "tier": 3,
             "time_estimate": 3.0,
             "stages": ["pre-push", "manual"],
-            "args": ["--ignore", "FURB184", "--ignore", "FURB120"],
+            "args": [],
             "files": "^crackerjack/.*\\.py$",
-            "exclude": r"^tests/.*\.py$",
+            "exclude": r"^tests/",
             "additional_dependencies": None,
             "types_or": None,
             "language": None,
@@ -357,7 +358,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "stages": ["pre-push", "manual"],
             "args": ["--config-file", "mypy.ini", "./crackerjack"],
             "files": None,
-            "exclude": None,
+            "exclude": r"^tests/",
             "additional_dependencies": None,
             "types_or": None,
             "language": "system",
@@ -459,33 +460,36 @@ PRE_COMMIT_TEMPLATE = """repos:
 class DynamicConfigGenerator:
     def __init__(self, package_directory: str | None = None) -> None:
         self.template = jinja2.Template(PRE_COMMIT_TEMPLATE)
-        self.package_directory = package_directory or self._detect_package_directory()
+        self.package_directory = self._sanitize_package_directory(
+            package_directory or self._detect_package_directory()
+        )
+
+    def _sanitize_package_directory(self, package_directory: str) -> str:
+        """Convert hyphens to underscores in package directory names."""
+        return package_directory.replace("-", "_")
 
     def _detect_package_directory(self) -> str:
         """Detect the package directory name for the current project."""
-        import os
         from pathlib import Path
 
         # Check if we're in the crackerjack project itself
-        current_dir = Path(os.getcwd())
+        current_dir = Path.cwd()
         if (current_dir / "crackerjack").exists() and (
             current_dir / "pyproject.toml"
         ).exists():
             # Check if this is actually the crackerjack project
-            try:
+            with suppress(Exception):
                 import tomllib
 
                 with (current_dir / "pyproject.toml").open("rb") as f:
                     data = tomllib.load(f)
                 if data.get("project", {}).get("name") == "crackerjack":
                     return "crackerjack"
-            except Exception:
-                pass
 
         # Try to read package name from pyproject.toml
         pyproject_path = current_dir / "pyproject.toml"
         if pyproject_path.exists():
-            try:
+            with suppress(Exception):
                 import tomllib
 
                 with pyproject_path.open("rb") as f:
@@ -496,8 +500,6 @@ class DynamicConfigGenerator:
                     # Check if package directory exists
                     if (current_dir / package_name).exists():
                         return package_name
-            except Exception:
-                pass
 
         # Fallback to project directory name
         if (current_dir / current_dir.name).exists():
@@ -542,7 +544,7 @@ class DynamicConfigGenerator:
         """Update hook configuration to use the detected package directory."""
         # Update skylos hook
         if hook["id"] == "skylos" and hook["args"]:
-            hook["args"] = [self.package_directory]
+            hook["args"] = [self.package_directory, "--exclude", "tests"]
 
         # Update zuban hook
         elif hook["id"] == "zuban" and hook["args"]:
@@ -564,12 +566,24 @@ class DynamicConfigGenerator:
                 "crackerjack", self.package_directory
             )
 
-        # Ensure hooks exclude src directories to avoid JavaScript conflicts
+        # Ensure hooks exclude src directories to avoid JavaScript conflicts and tests
         if hook["exclude"]:
+            # Add src exclusion if not present
             if "src/" not in hook["exclude"]:
                 hook["exclude"] = f"{hook['exclude']}|^src/"
         else:
-            hook["exclude"] = "^src/"
+            # If no exclusion, add both tests and src
+            if hook["id"] in (
+                "skylos",
+                "zuban",
+                "bandit",
+                "refurb",
+                "complexipy",
+                "pyright",
+            ):
+                hook["exclude"] = r"^tests/|^src/"
+            else:
+                hook["exclude"] = "^src/"
 
         return hook
 
