@@ -1,10 +1,4 @@
 #!/usr/bin/env python3
-"""
-AI Agent Audit System
-
-Comprehensive audit of all agents to ensure they are optimized for their tasks
-and integrate effectively with the crackerjack workflow.
-"""
 
 import ast
 import asyncio
@@ -16,7 +10,6 @@ from typing import Any
 from rich.console import Console
 from rich.table import Table
 
-# Add project to path for imports
 sys.path.insert(0, str(Path(__file__).parent))
 
 from crackerjack.agents.base import (
@@ -31,52 +24,41 @@ from crackerjack.agents.base import (
 
 @dataclass
 class AgentAuditResult:
-    """Results of auditing a single agent."""
-
     agent_name: str
     class_name: str
     file_path: str
 
-    # Implementation Quality
     has_can_handle: bool = False
     has_analyze_and_fix: bool = False
     has_get_supported_types: bool = False
     confidence_range_valid: bool = False
 
-    # Performance Characteristics
     estimated_complexity: int = 0
     method_count: int = 0
     lines_of_code: int = 0
     has_async_methods: bool = False
 
-    # Integration Quality
     supported_issue_types: set[IssueType] = field(default_factory=set)
     confidence_scores: dict[IssueType, float] = field(default_factory=dict)
     integration_issues: list[str] = field(default_factory=list)
 
-    # Optimization Recommendations
     recommendations: list[str] = field(default_factory=list)
     critical_issues: list[str] = field(default_factory=list)
-    performance_score: float = 0.0  # 0-100
+    performance_score: float = 0.0
 
-    # Functional Testing Results
     instantiation_success: bool = False
     mock_issue_handling: dict[str, Any] = field(default_factory=dict)
 
 
 class AgentAuditor:
-    """Audits AI agents for optimization and integration."""
-
     def __init__(self, console: Console | None = None):
         self.console = console or Console()
         self.agent_results: list[AgentAuditResult] = []
 
     async def audit_all_agents(self) -> list[AgentAuditResult]:
-        """Audit all registered agents."""
-        self.console.print("🔍 [bold]Starting Comprehensive Agent Audit[/bold]")
+        self.console.print("🔍 [bold]Starting Comprehensive Agent Audit[/ bold]")
 
-        # Get all agent files
-        agent_files = list(Path("crackerjack/agents").glob("*.py"))
+        agent_files = list(Path("crackerjack / agents").glob("*.py"))
         agent_files = [
             f for f in agent_files if f.name not in ["__init__.py", "base.py"]
         ]
@@ -91,10 +73,8 @@ class AgentAuditor:
             except Exception as e:
                 self.console.print(f"❌ Failed to audit {agent_file}: {e}")
 
-        # Audit registered agents
         await self._audit_registered_agents()
 
-        # Generate recommendations
         self._generate_audit_recommendations()
 
         return self.agent_results
@@ -102,10 +82,8 @@ class AgentAuditor:
     async def _audit_single_agent_file(
         self, agent_file: Path
     ) -> AgentAuditResult | None:
-        """Audit a single agent file."""
         self.console.print(f"🔍 Auditing {agent_file.name}")
 
-        # Parse source code
         try:
             source = agent_file.read_text()
             tree = ast.parse(source)
@@ -113,11 +91,9 @@ class AgentAuditor:
             self.console.print(f"❌ Failed to parse {agent_file}: {e}")
             return None
 
-        # Find agent classes
         agent_classes = []
         for node in ast.walk(tree):
             if isinstance(node, ast.ClassDef):
-                # Check if it's an agent (inherits from SubAgent or has Agent in name)
                 is_agent = "Agent" in node.name or any(
                     isinstance(base, ast.Name) and base.id == "SubAgent"
                     for base in node.bases
@@ -128,7 +104,6 @@ class AgentAuditor:
         if not agent_classes:
             return None
 
-        # Audit the first agent class found
         agent_class = agent_classes[0]
         result = AgentAuditResult(
             agent_name=agent_class.name,
@@ -136,7 +111,6 @@ class AgentAuditor:
             file_path=str(agent_file),
         )
 
-        # Analyze implementation
         await self._analyze_agent_implementation(agent_class, source, result)
 
         return result
@@ -144,21 +118,15 @@ class AgentAuditor:
     async def _analyze_agent_implementation(
         self, class_node: ast.ClassDef, source: str, result: AgentAuditResult
     ):
-        """Analyze agent implementation quality."""
-        # Extract method analysis
         self._analyze_methods(class_node, result)
 
-        # Extract complexity analysis
         self._analyze_complexity(class_node, source, result)
 
-        # Extract quality scoring
         self._calculate_quality_score(result)
 
-        # Extract recommendations
         self._generate_quality_recommendations(result)
 
     def _analyze_methods(self, class_node: ast.ClassDef, result: AgentAuditResult):
-        """Analyze methods and check for required methods."""
         method_names = []
         async_methods = 0
 
@@ -177,7 +145,6 @@ class AgentAuditor:
         result.method_count = len(method_names)
         result.has_async_methods = async_methods > 0
 
-        # Check required methods
         result.has_can_handle = "can_handle" in method_names
         result.has_analyze_and_fix = "analyze_and_fix" in method_names
         result.has_get_supported_types = "get_supported_types" in method_names
@@ -185,20 +152,17 @@ class AgentAuditor:
     def _analyze_complexity(
         self, class_node: ast.ClassDef, source: str, result: AgentAuditResult
     ):
-        """Analyze complexity and lines of code."""
         result.lines_of_code = len(
             [line for line in source.split("\n") if line.strip()]
         )
         result.estimated_complexity = self._estimate_complexity(class_node)
 
-        # Check for critical issues
         if not result.has_can_handle:
             result.critical_issues.append("Missing required can_handle method")
         if not result.has_analyze_and_fix:
             result.critical_issues.append("Missing required analyze_and_fix method")
 
     def _calculate_quality_score(self, result: AgentAuditResult):
-        """Calculate performance score based on implementation quality."""
         score = 100
         if not result.has_can_handle:
             score -= 30
@@ -214,7 +178,6 @@ class AgentAuditor:
         result.performance_score = max(0, score)
 
     def _generate_quality_recommendations(self, result: AgentAuditResult):
-        """Generate recommendations based on analysis."""
         if result.estimated_complexity > 15:
             result.recommendations.append("Consider breaking down complex methods")
         if result.lines_of_code > 300:
@@ -227,8 +190,7 @@ class AgentAuditor:
             )
 
     def _estimate_complexity(self, class_node: ast.ClassDef) -> int:
-        """Estimate cyclomatic complexity of the class."""
-        complexity = 1  # Base complexity
+        complexity = 1
 
         for node in ast.walk(class_node):
             if isinstance(node, ast.If | ast.While | ast.For | ast.ExceptHandler):
@@ -239,13 +201,11 @@ class AgentAuditor:
         return complexity
 
     async def _audit_registered_agents(self):
-        """Test agents that are properly registered."""
         self.console.print("🧪 Testing registered agents...")
 
         context = AgentContext(project_path=Path.cwd())
 
         for agent_name, agent_class in agent_registry._agents.items():
-            # Find existing result or create new one
             existing_result = None
             for result in self.agent_results:
                 if result.agent_name == agent_name:
@@ -258,16 +218,13 @@ class AgentAuditor:
                 )
                 self.agent_results.append(existing_result)
 
-            # Test instantiation
             try:
                 agent = agent_class(context)
                 existing_result.instantiation_success = True
 
-                # Test supported types
                 if hasattr(agent, "get_supported_types"):
                     existing_result.supported_issue_types = agent.get_supported_types()
 
-                # Test confidence scoring
                 await self._test_agent_confidence(agent, existing_result)
 
             except Exception as e:
@@ -275,7 +232,6 @@ class AgentAuditor:
                 existing_result.instantiation_success = False
 
     async def _test_agent_confidence(self, agent: SubAgent, result: AgentAuditResult):
-        """Test agent confidence scoring with mock issues."""
         test_issues = {
             IssueType.COMPLEXITY: Issue(
                 id="test1",
@@ -322,7 +278,6 @@ class AgentAuditor:
                 confidence = await agent.can_handle(issue)
                 result.confidence_scores[issue_type] = confidence
 
-                # Validate confidence range
                 if 0.0 <= confidence <= 1.0:
                     valid_confidences += 1
                 else:
@@ -343,10 +298,8 @@ class AgentAuditor:
             result.critical_issues.append("Invalid confidence scores returned")
 
     def _generate_audit_recommendations(self):
-        """Generate overall audit recommendations."""
         self.console.print("📊 Generating audit recommendations...")
 
-        # Overall statistics
         total_agents = len(self.agent_results)
         working_agents = sum(1 for r in self.agent_results if r.instantiation_success)
         critical_issues_count = sum(len(r.critical_issues) for r in self.agent_results)
@@ -356,7 +309,6 @@ class AgentAuditor:
         )
         self.console.print(f"🚨 Critical Issues: {critical_issues_count} total")
 
-        # Identify problematic agents
         problematic_agents = [
             r for r in self.agent_results if len(r.critical_issues) > 0
         ]
@@ -365,22 +317,19 @@ class AgentAuditor:
                 f"⚠️ Problematic Agents: {[r.agent_name for r in problematic_agents]}"
             )
 
-        # Performance analysis
         avg_performance = sum(r.performance_score for r in self.agent_results) / len(
             self.agent_results
         )
-        self.console.print(f"📊 Average Performance Score: {avg_performance:.1f}/100")
+        self.console.print(f"📊 Average Performance Score: {avg_performance: .1f}/ 100")
 
-        # Top performers
         top_performers = sorted(
             self.agent_results, key=lambda r: r.performance_score, reverse=True
         )[:3]
         self.console.print(
-            f"🏆 Top Performers: {[(r.agent_name, f'{r.performance_score:.1f}') for r in top_performers]}"
+            f"🏆 Top Performers: {[(r.agent_name, f'{r.performance_score: .1f}') for r in top_performers]}"
         )
 
     def create_audit_table(self) -> Table:
-        """Create audit results table."""
         table = Table(
             title="AI Agent Audit Results",
             show_header=True,
@@ -398,7 +347,6 @@ class AgentAuditor:
         for result in sorted(
             self.agent_results, key=lambda r: r.performance_score, reverse=True
         ):
-            # Status determination
             status_text = "✅ GOOD"
             status_color = "green"
 
@@ -418,7 +366,7 @@ class AgentAuditor:
 
             table.add_row(
                 result.agent_name,
-                f"{result.performance_score:.1f}",
+                f"{result.performance_score: .1f}",
                 str(result.method_count),
                 str(result.lines_of_code),
                 str(result.estimated_complexity),
@@ -429,7 +377,6 @@ class AgentAuditor:
         return table
 
     def save_detailed_report(self):
-        """Save detailed audit report."""
         import json
         from datetime import datetime
 
@@ -487,29 +434,22 @@ class AgentAuditor:
 
 
 async def main():
-    """Run complete agent audit."""
     console = Console()
     auditor = AgentAuditor(console)
 
-    # Run audit
     results = await auditor.audit_all_agents()
 
-    # Display results
     console.print("\n")
     console.print(auditor.create_audit_table())
 
-    # Critical issues summary
     critical_agents = [r for r in results if len(r.critical_issues) > 0]
     if critical_agents:
         console.print(
-            f"\n🚨 [bold red]CRITICAL: {len(critical_agents)} agents have critical issues[/bold red]"
+            f"\n🚨 [bold red]CRITICAL: {len(critical_agents)} agents have critical issues[/ bold red]"
         )
         for agent in critical_agents:
-            console.print(
-                f"   • {agent.agent_name}: {'; '.join(agent.critical_issues)}"
-            )
+            console.print(f" • {agent.agent_name}: {'; '.join(agent.critical_issues)}")
 
-    # Save detailed report
     auditor.save_detailed_report()
 
     console.print(f"\n✅ Audit complete: {len(results)} agents analyzed")
