@@ -1,5 +1,3 @@
-"""Strategic test coverage for core/enhanced_container.py - Enhanced dependency injection."""
-
 import threading
 from pathlib import Path
 from unittest.mock import Mock, patch
@@ -25,8 +23,6 @@ from crackerjack.models.protocols import (
 
 
 class MockService:
-    """Mock service for testing."""
-
     def __init__(self, value: str = "test") -> None:
         self.value = value
         self.disposed = False
@@ -36,23 +32,17 @@ class MockService:
 
 
 class MockDependentService:
-    """Mock service with dependencies for testing."""
-
     def __init__(self, dependency: MockService) -> None:
         self.dependency = dependency
 
 
 class TestServiceLifetime:
-    """Test ServiceLifetime enum."""
-
     def test_service_lifetime_values(self) -> None:
-        """Test that ServiceLifetime enum has expected values."""
         assert ServiceLifetime.SINGLETON.value == "singleton"
         assert ServiceLifetime.TRANSIENT.value == "transient"
         assert ServiceLifetime.SCOPED.value == "scoped"
 
     def test_service_lifetime_enum_members(self) -> None:
-        """Test ServiceLifetime enum members."""
         lifetimes = list(ServiceLifetime)
         assert len(lifetimes) == 3
         assert ServiceLifetime.SINGLETON in lifetimes
@@ -61,10 +51,7 @@ class TestServiceLifetime:
 
 
 class TestServiceDescriptor:
-    """Test ServiceDescriptor class."""
-
     def test_descriptor_with_implementation(self) -> None:
-        """Test descriptor with implementation class."""
         descriptor = ServiceDescriptor(
             interface=MockService,
             implementation=MockService,
@@ -80,8 +67,6 @@ class TestServiceDescriptor:
         assert descriptor.dependencies == []
 
     def test_descriptor_with_factory(self) -> None:
-        """Test descriptor with factory function."""
-
         def mock_factory():
             return MockService()
 
@@ -97,7 +82,6 @@ class TestServiceDescriptor:
         assert descriptor.lifetime == ServiceLifetime.TRANSIENT
 
     def test_descriptor_with_instance(self) -> None:
-        """Test descriptor with pre-created instance."""
         instance = MockService("test_instance")
 
         descriptor = ServiceDescriptor(
@@ -112,7 +96,6 @@ class TestServiceDescriptor:
         assert descriptor.factory is None
 
     def test_descriptor_validation_error(self) -> None:
-        """Test descriptor validation when no source provided."""
         with pytest.raises(
             ValueError,
             match="Must provide either implementation, factory, or instance",
@@ -120,7 +103,6 @@ class TestServiceDescriptor:
             ServiceDescriptor(interface=MockService)
 
     def test_descriptor_with_dependencies(self) -> None:
-        """Test descriptor with dependencies list."""
         descriptor = ServiceDescriptor(
             interface=MockDependentService,
             implementation=MockDependentService,
@@ -132,33 +114,25 @@ class TestServiceDescriptor:
 
 
 class TestServiceScope:
-    """Test ServiceScope class."""
-
     def test_scope_creation(self) -> None:
-        """Test service scope creation."""
         scope = ServiceScope("test_scope")
 
         assert scope.name == "test_scope"
         assert scope._instances == {}
 
     def test_scope_instance_management(self) -> None:
-        """Test getting and setting scoped instances."""
         scope = ServiceScope("test")
         service = MockService("scoped")
 
-        # Initially no instance
         assert scope.get_instance("test_key") is None
 
-        # Set instance
         scope.set_instance("test_key", service)
 
-        # Get instance
         retrieved = scope.get_instance("test_key")
         assert retrieved is service
         assert retrieved.value == "scoped"
 
     def test_scope_dispose(self) -> None:
-        """Test scope disposal."""
         scope = ServiceScope("test")
         service1 = MockService("service1")
         service2 = MockService("service2")
@@ -166,34 +140,26 @@ class TestServiceScope:
         scope.set_instance("key1", service1)
         scope.set_instance("key2", service2)
 
-        # Dispose scope
         scope.dispose()
 
-        # Services should be disposed
         assert service1.disposed
         assert service2.disposed
 
-        # Instances should be cleared
         assert scope._instances == {}
 
     def test_scope_dispose_with_error(self) -> None:
-        """Test scope disposal with error handling."""
         scope = ServiceScope("test")
 
-        # Create mock service that raises error on dispose
         failing_service = Mock()
         failing_service.dispose.side_effect = Exception("Dispose error")
 
         scope.set_instance("failing", failing_service)
 
-        # Should not raise error, just log it
         scope.dispose()
 
-        # Should still clear instances
         assert scope._instances == {}
 
     def test_scope_thread_safety(self) -> None:
-        """Test scope thread safety."""
         scope = ServiceScope("threaded")
         results = []
 
@@ -218,25 +184,19 @@ class TestServiceScope:
 
 
 class TestDependencyResolver:
-    """Test DependencyResolver class."""
-
     @pytest.fixture
     def container(self):
-        """Create enhanced container for testing."""
         return EnhancedDependencyContainer("test")
 
     @pytest.fixture
     def resolver(self, container):
-        """Create dependency resolver."""
         return DependencyResolver(container)
 
     def test_resolver_creation(self, container) -> None:
-        """Test dependency resolver creation."""
         resolver = DependencyResolver(container)
         assert resolver.container is container
 
     def test_create_instance_with_instance(self, resolver) -> None:
-        """Test creating instance when descriptor has pre-created instance."""
         instance = MockService("pre_created")
         descriptor = ServiceDescriptor(interface=MockService, instance=instance)
 
@@ -244,8 +204,6 @@ class TestDependencyResolver:
         assert result is instance
 
     def test_create_instance_with_factory(self, resolver) -> None:
-        """Test creating instance with factory function."""
-
         def mock_factory():
             return MockService("from_factory")
 
@@ -256,7 +214,6 @@ class TestDependencyResolver:
         assert result.value == "from_factory"
 
     def test_create_instance_with_implementation(self, resolver) -> None:
-        """Test creating instance with implementation class."""
         descriptor = ServiceDescriptor(
             interface=MockService,
             implementation=MockService,
@@ -268,8 +225,6 @@ class TestDependencyResolver:
     def test_create_instance_with_dependency_injection(
         self, resolver, container
     ) -> None:
-        """Test creating instance with dependency injection."""
-        # Register dependency
         container.register_singleton(MockService, implementation=MockService)
 
         descriptor = ServiceDescriptor(
@@ -282,8 +237,6 @@ class TestDependencyResolver:
         assert isinstance(result.dependency, MockService)
 
     def test_create_instance_invalid_descriptor(self, resolver) -> None:
-        """Test creating instance with invalid descriptor."""
-        # Create descriptor with invalid state (bypassing validation)
         descriptor = ServiceDescriptor.__new__(ServiceDescriptor)
         descriptor.interface = MockService
         descriptor.implementation = None
@@ -297,8 +250,6 @@ class TestDependencyResolver:
             resolver.create_instance(descriptor)
 
     def test_factory_with_dependencies(self, resolver, container) -> None:
-        """Test factory function with dependency injection."""
-        # Register dependency
         container.register_singleton(MockService, implementation=MockService)
 
         def factory_with_dep(dependency: MockService):
@@ -315,10 +266,7 @@ class TestDependencyResolver:
 
 
 class TestEnhancedDependencyContainer:
-    """Test EnhancedDependencyContainer class."""
-
     def test_container_creation(self) -> None:
-        """Test container creation."""
         container = EnhancedDependencyContainer("test_container")
 
         assert container.name == "test_container"
@@ -328,18 +276,14 @@ class TestEnhancedDependencyContainer:
         assert isinstance(container.resolver, DependencyResolver)
 
     def test_register_singleton(self) -> None:
-        """Test registering singleton service."""
         container = EnhancedDependencyContainer()
 
         result = container.register_singleton(MockService, implementation=MockService)
 
-        # Should return self for chaining
         assert result is container
 
-        # Should be registered
         assert container.is_registered(MockService)
 
-        # Check descriptor
         key = container._get_service_key(MockService)
         descriptor = container._services[key]
         assert descriptor.interface == MockService
@@ -347,7 +291,6 @@ class TestEnhancedDependencyContainer:
         assert descriptor.lifetime == ServiceLifetime.SINGLETON
 
     def test_register_transient(self) -> None:
-        """Test registering transient service."""
         container = EnhancedDependencyContainer()
 
         def mock_factory():
@@ -364,7 +307,6 @@ class TestEnhancedDependencyContainer:
         assert descriptor.lifetime == ServiceLifetime.TRANSIENT
 
     def test_register_scoped(self) -> None:
-        """Test registering scoped service."""
         container = EnhancedDependencyContainer()
 
         result = container.register_scoped(MockService, implementation=MockService)
@@ -377,24 +319,19 @@ class TestEnhancedDependencyContainer:
         assert descriptor.lifetime == ServiceLifetime.SCOPED
 
     def test_get_singleton_service(self) -> None:
-        """Test getting singleton service."""
         container = EnhancedDependencyContainer()
         container.register_singleton(MockService, implementation=MockService)
 
-        # First call should create instance
         instance1 = container.get(MockService)
         assert isinstance(instance1, MockService)
 
-        # Second call should return same instance
         instance2 = container.get(MockService)
         assert instance1 is instance2
 
     def test_get_transient_service(self) -> None:
-        """Test getting transient service."""
         container = EnhancedDependencyContainer()
         container.register_transient(MockService, implementation=MockService)
 
-        # Each call should create new instance
         instance1 = container.get(MockService)
         instance2 = container.get(MockService)
 
@@ -403,22 +340,18 @@ class TestEnhancedDependencyContainer:
         assert instance1 is not instance2
 
     def test_get_scoped_service(self) -> None:
-        """Test getting scoped service."""
         container = EnhancedDependencyContainer()
         container.register_scoped(MockService, implementation=MockService)
 
         scope = container.create_scope("test_scope")
 
-        # First call should create instance in scope
         instance1 = container.get(MockService, scope)
         assert isinstance(instance1, MockService)
 
-        # Second call should return same scoped instance
         instance2 = container.get(MockService, scope)
         assert instance1 is instance2
 
     def test_get_scoped_service_without_scope(self) -> None:
-        """Test getting scoped service without providing scope."""
         container = EnhancedDependencyContainer()
         container.register_scoped(MockService, implementation=MockService)
 
@@ -426,27 +359,22 @@ class TestEnhancedDependencyContainer:
             container.get(MockService)
 
     def test_get_unregistered_service(self) -> None:
-        """Test getting unregistered service."""
         container = EnhancedDependencyContainer()
 
         with pytest.raises(ValueError, match="Service MockService not registered"):
             container.get(MockService)
 
     def test_get_optional_service(self) -> None:
-        """Test getting optional service."""
         container = EnhancedDependencyContainer()
 
-        # Not registered, should return default
         result = container.get_optional(MockService, "default")
         assert result == "default"
 
-        # Register and get
         container.register_singleton(MockService, implementation=MockService)
         result = container.get_optional(MockService)
         assert isinstance(result, MockService)
 
     def test_is_registered(self) -> None:
-        """Test checking if service is registered."""
         container = EnhancedDependencyContainer()
 
         assert not container.is_registered(MockService)
@@ -455,7 +383,6 @@ class TestEnhancedDependencyContainer:
         assert container.is_registered(MockService)
 
     def test_create_scope(self) -> None:
-        """Test creating service scope."""
         container = EnhancedDependencyContainer()
 
         scope = container.create_scope("custom_scope")
@@ -463,7 +390,6 @@ class TestEnhancedDependencyContainer:
         assert scope.name == "custom_scope"
 
     def test_set_current_scope(self) -> None:
-        """Test setting current scope."""
         container = EnhancedDependencyContainer()
         scope = ServiceScope("test")
 
@@ -474,7 +400,6 @@ class TestEnhancedDependencyContainer:
         assert container._current_scope is None
 
     def test_get_service_info(self) -> None:
-        """Test getting service information."""
         container = EnhancedDependencyContainer()
         container.register_singleton(MockService, implementation=MockService)
         container.register_transient(
@@ -486,7 +411,6 @@ class TestEnhancedDependencyContainer:
 
         assert len(info) == 2
 
-        # Check singleton info
         singleton_key = container._get_service_key(MockService)
         singleton_info = info[singleton_key]
         assert singleton_info["interface"] == "MockService"
@@ -496,35 +420,26 @@ class TestEnhancedDependencyContainer:
         assert singleton_info["has_instance"] is False
 
     def test_dispose_container(self) -> None:
-        """Test disposing container."""
         container = EnhancedDependencyContainer()
         container.register_singleton(MockService, implementation=MockService)
 
-        # Create singleton instance
         instance = container.get(MockService)
         assert isinstance(instance, MockService)
 
-        # Create and set scope
         scope = ServiceScope("test")
         container.set_current_scope(scope)
 
-        # Dispose container
         container.dispose()
 
-        # Should clear singletons and scope
         assert container._singletons == {}
         assert container._current_scope is None
 
     def test_context_manager(self) -> None:
-        """Test container as context manager."""
         with EnhancedDependencyContainer("context_test") as container:
             container.register_singleton(MockService, implementation=MockService)
             assert container.name == "context_test"
 
-        # Container should be disposed after context
-
     def test_service_key_generation(self) -> None:
-        """Test service key generation."""
         container = EnhancedDependencyContainer()
 
         key = container._get_service_key(MockService)
@@ -533,10 +448,7 @@ class TestEnhancedDependencyContainer:
 
 
 class TestServiceCollectionBuilder:
-    """Test ServiceCollectionBuilder class."""
-
     def test_builder_creation(self) -> None:
-        """Test builder creation."""
         container = EnhancedDependencyContainer()
         builder = ServiceCollectionBuilder(container)
 
@@ -546,17 +458,15 @@ class TestServiceCollectionBuilder:
         assert builder.dry_run is False
 
     def test_builder_configuration(self) -> None:
-        """Test builder configuration methods."""
         container = EnhancedDependencyContainer()
         console = Console()
-        pkg_path = Path("/test")
+        pkg_path = Path("/ test")
 
         builder = ServiceCollectionBuilder(container)
         result = (
             builder.with_console(console).with_package_path(pkg_path).with_dry_run(True)
         )
 
-        # Should return self for chaining
         assert result is builder
 
         assert builder.console is console
@@ -564,7 +474,6 @@ class TestServiceCollectionBuilder:
         assert builder.dry_run is True
 
     def test_builder_build(self) -> None:
-        """Test builder build method."""
         container = EnhancedDependencyContainer()
         builder = ServiceCollectionBuilder(container)
 
@@ -572,10 +481,9 @@ class TestServiceCollectionBuilder:
         assert result is container
 
     def test_add_core_services(self) -> None:
-        """Test adding core services."""
         container = EnhancedDependencyContainer()
         console = Console()
-        pkg_path = Path("/test")
+        pkg_path = Path("/ test")
 
         builder = ServiceCollectionBuilder(container)
 
@@ -592,10 +500,8 @@ class TestServiceCollectionBuilder:
                 .add_core_services()
             )
 
-            # Should return self for chaining
             assert result is builder
 
-            # Should register core services
             assert container.is_registered(FileSystemInterface)
             assert container.is_registered(GitInterface)
             assert container.is_registered(HookManager)
@@ -603,35 +509,28 @@ class TestServiceCollectionBuilder:
             assert container.is_registered(PublishManager)
 
     def test_add_configuration_services(self) -> None:
-        """Test adding configuration services - simplified version."""
         container = EnhancedDependencyContainer()
         console = Console()
-        pkg_path = Path("/test")
+        pkg_path = Path("/ test")
 
         builder = ServiceCollectionBuilder(container)
         result = builder.with_console(console).with_package_path(pkg_path)
 
-        # Test builder configuration without complex imports
         assert result is builder
         assert builder.console is console
         assert builder.pkg_path == pkg_path
 
 
 class TestCreateEnhancedContainer:
-    """Test create_enhanced_container factory function - basic functionality."""
-
     def test_container_creation_basic(self) -> None:
-        """Test basic container creation functionality."""
-        # Test basic container creation without complex service registration
         container = EnhancedDependencyContainer("test")
         assert isinstance(container, EnhancedDependencyContainer)
         assert container.name == "test"
 
     def test_service_collection_builder_basic(self) -> None:
-        """Test ServiceCollectionBuilder basic functionality."""
         container = EnhancedDependencyContainer("builder_test")
         console = Console()
-        pkg_path = Path("/test")
+        pkg_path = Path("/ test")
 
         builder = ServiceCollectionBuilder(container)
         result = (
@@ -645,7 +544,6 @@ class TestCreateEnhancedContainer:
         assert builder.dry_run is True
 
     def test_builder_build_returns_container(self) -> None:
-        """Test that builder build returns the container."""
         container = EnhancedDependencyContainer("build_test")
         builder = ServiceCollectionBuilder(container)
 
@@ -654,50 +552,38 @@ class TestCreateEnhancedContainer:
 
 
 class TestIntegrationScenarios:
-    """Integration test scenarios."""
-
     def test_full_dependency_injection_scenario(self) -> None:
-        """Test complete dependency injection scenario."""
         container = EnhancedDependencyContainer("integration_test")
 
-        # Register services with dependencies
         container.register_singleton(MockService, implementation=MockService)
         container.register_transient(
             MockDependentService,
             implementation=MockDependentService,
         )
 
-        # Get dependent service - should inject MockService
         dependent = container.get(MockDependentService)
 
         assert isinstance(dependent, MockDependentService)
         assert isinstance(dependent.dependency, MockService)
 
-        # Get another dependent service - should reuse singleton MockService
         dependent2 = container.get(MockDependentService)
-        assert dependent.dependency is dependent2.dependency  # Same singleton instance
+        assert dependent.dependency is dependent2.dependency
 
     def test_scoped_service_lifecycle(self) -> None:
-        """Test scoped service lifecycle."""
         container = EnhancedDependencyContainer("scope_test")
         container.register_scoped(MockService, implementation=MockService)
 
-        # Create two scopes
         scope1 = container.create_scope("scope1")
         scope2 = container.create_scope("scope2")
 
-        # Get service in each scope
         service1a = container.get(MockService, scope1)
-        service1b = container.get(MockService, scope1)  # Same scope
-        service2 = container.get(MockService, scope2)  # Different scope
+        service1b = container.get(MockService, scope1)
+        service2 = container.get(MockService, scope2)
 
-        # Services in same scope should be identical
         assert service1a is service1b
 
-        # Services in different scopes should be different
         assert service1a is not service2
 
-        # Dispose scopes
         scope1.dispose()
         scope2.dispose()
 
@@ -705,11 +591,9 @@ class TestIntegrationScenarios:
         assert service2.disposed
 
     def test_builder_pattern_integration(self) -> None:
-        """Test builder pattern integration - simplified version."""
         console = Console()
-        pkg_path = Path("/test")
+        pkg_path = Path("/ test")
 
-        # Use builder pattern to create configured container
         container = (
             ServiceCollectionBuilder(EnhancedDependencyContainer("builder_test"))
             .with_console(console)
@@ -721,7 +605,6 @@ class TestIntegrationScenarios:
         assert container.name == "builder_test"
         assert isinstance(container, EnhancedDependencyContainer)
 
-        # Test builder retained configuration
         builder = ServiceCollectionBuilder(container)
         builder.with_console(console).with_package_path(pkg_path)
         assert builder.console is console
